# combo - content management system
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms

from .models import Page, ParametersCell, MenuCell
from jsonfield.widgets import JSONWidget

class ParametersForm(forms.Form):
    choice = forms.ChoiceField(choices=[])

    def __init__(self, *args, **kwargs):
        self.parameters = kwargs.pop('parameters')
        empty_label = kwargs.pop('empty_label')
        super(ParametersForm, self).__init__(*args, **kwargs)
        self.fields['choice'].choices = [('', empty_label)] + [(x['name'], x['name']) for x in self.parameters]

    def clean(self):
        choice = self.cleaned_data.get('choice')
        for parameter in self.parameters:
            if parameter['name'] == choice:
                self.cleaned_data['choice'] = parameter['value']
                break
        return self.cleaned_data

class ParametersCellForm(forms.ModelForm):
    class Meta:
        model = ParametersCell
        fields = ('title', 'url', 'empty_label', 'parameters',)
        widgets = {
            # XXX: replace with a more ergonomic widget
            'parameters': JSONWidget(
                attrs={
                    'rows': 30,
                    'cols': 100,
                    'style': 'resize: none'
                })
        }


class MenuCellForm(forms.ModelForm):
    class Meta:
        model = MenuCell
        fields = ('depth', 'initial_level', 'root_page')

    def __init__(self, *args, **kwargs):
        super(MenuCellForm, self).__init__(*args, **kwargs)
        pages = Page.get_as_reordered_flat_hierarchy(Page.objects.all())
        choices = [(x.id, '%s %s' % (u'\u00a0' * x.level * 2, x.title)) for x in pages]
        self.fields['root_page'].widget = forms.Select(choices=choices)
